@@ -1,5 +1,6 @@
 from flask_modals.modal import (
     Modal,
     render_template_modal,
-    render_template_redirect
+    render_template_redirect,
+    redirect_to
 )
